Welcome to our World! Where we serve you cookies to ensure you get the best viewing experience on our site.

Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?

Register or sign in here: ucp.php?mode=register

15x01 - An Unconventional Launch Party

Episode transcripts for the TV show, "Project Runway". Aired: December 1, 2004 – present.*
Watch/Buy Amazon


Contestants compete with each other to create the best clothes and are restricted by time, materials and theme.

15x01 - An Unconventional Launch Party

Post by bunniefuu »

HEIDI:
This season on...

Let's go!

-I think it's dope.
-[screaming]

[bleep]

TIM:
Here we have



The sparks are
quite literally flying.

Our first ever pop-up shop.

Yeah!

And then look, watch.

Oh my God.

It's very ballsy.

I cannot go home yet.

If you are going to cry,
go outside.

Just sit your [bleep] a*s down

and calm the [bleep] down.

-Oh, hell no!
-[bleep]

HEIDI:
Lights please.

♪ ♪

Guest judge, Priyanka Chopra.

Kelly Osbourne.
Nina Dobrev.

Emily Ratajkowski

This was one of
my favorite pieces

I've seen in many seasons.

HEIDI:
And you did it here first.

It's kind of sad.

NINA: Who is this
bland person?

Fashion isn't fair.

Does that mean you gave up?

♪ ♪

♪ ♪

[distorted car horn]

I can't believe this.

I cannot believe I'm here!

I'm absolutely a hustler.

I try every day to hustle harder
than the day before.

I still don't even think
that it's fully hit me yet

that I'm in New York.

When my dad dropped me off

at the airport,

his eyes starting tearing up,

and he said, "Remember to say,
'yes ma'am,' and 'yes sir,'

and... to win, [bleep] it!"

Fashion is actually not

what I first started out doing.

I actually studied herpetology
at Berkeley.

I thought, "I don't know
that I can fully commit

to being bit every day for
the rest of my life."

Which is funny that I moved into
fashion, because it's kind of

a similar thing,
it's just, like,

not actual blood, but people
are kind of cutthroat.

The point of me being here

as far as I'm concerned,
is to show off my work.

I'm gonna do what I want to do.
My mother has said

that she hasn't been able
to tell me what to do

since I was nine years old.

This is so nice!

I feel really special
walking into this room,

because I didn't
want to touch nothing,

it looked so good.

-Hey, how you doing?
-Hi! Good, how are you?

-I'm Tasha.
-I'm Ian, nice to meet you.

Nice to meet you.

-We're the first ones, right?
-Yes.

In my hometown,
Shreveport, Louisiana,

the girls with all

the overdone makeup,
and skintight dresses,

and that is not me. [laughs]

I design for the girls that
don't like to wear heels.

The tomboys.

The girls that like to
stay relaxed but look chic.

A lot of people
have told me that,

"You don't seem like the type
to be designing."

I never knew that
a designer had a look.

-TASHA: Hey.
-Hey, guys!

I was gonna wear
that same outfit.

[laughter]

So, what kind of stuff
do you do?

I make clothes and art.

[laughter]

My aesthetic is humorous,

playful, but also, with, like,

a little bit of,
like, a seriousness to it.

There's always like,
some twist.

-I just finished up school.
So, I just graduated. -Oh, cool.

I grew up partially Mormon.

I didn't have a lot of exposure
to Internet.

My ex-stepdad would lock
the computer away.

But I'm smart.

I think I'm smart. [laughs]

Hooray. [laughs]

I've been designing

for almost ten years.

At the beginning, I wanted to
go to architecture school.

But I wanted to
see results faster.

Hey, I'm Tasha.

I was a designer

in Venezuela,
back home in Caracas.

But political situation,
it's kind of difficult

to succeed as

a fashion designer there.

-It must be so crazy.
-Yeah.

There's, like, so much drama
going on over there.

Well, welcome.
I'm happy you're here.

-Cheers.
-Yes!

How badly do I want to do
in this competition?

I want to do so well.

I want to do well
for other women

at my age.

This is my chance
to reinvent myself.

And I don't want to blow it.

Hi guy... oh, [bleep]!
Nathalia?

-Corey?
-[laughs]

What's going on, girl?

I'm freaking out because

I know Corey 'cause I went to
school with him.

We did shows together,
we competed together.

And I beat him.

Me and Nathalia do have
a little rivalry

So, it's gonna be...
really interesting.

See what happens
when you come in last?

I know, right? I'm sorry.

There's no more
champagne glasses,

and I had to use a mug.

Shut up.

-[cheering and applause]
-Hello!

-Hi!
-HEIDI: Hi, guys!

Hi!

Mr. Gunn

and Mrs. Heidi walked
through this door.

-Hi, everyone.
-Hi!

-Welcome!
[laughter]

I want to welcome all of you

to Season 15 of
Project Runway !

[cheering, applause]

We've still got it.

-The magic.
-We do.

We have a lot of surprises for
you this season.

-Uh-oh.
-Uh-oh.

And the first of which
is right now.

-This is it.
-Your first challenge

is starting immediately.

-Oh, my God.
-Wow.

I've had two glasses
of champagne

and I'm like, thank God
I put that second glass down.

We want you to take the spirit,

the aura and the vibe of this

fabulous launch party,
and incorporate those elements

into your first look.

I'm excited, like, to make
a c*ck dress is fun.

Like, yes!
Like, I can do this.

We actually want you
to take a little bit more

than just the spirit.

Whatever we decorated
this beautiful party with...

...are your materials.

Oh, [bleep].

HEIDI:
So, you grab whatever you can.

If it's not nailed down,
it's yours.

-Now?
-Not yet.

HEIDI:
You have exactly five minutes.

Are you ready?

ALL:
Yes!

On your mark...

Let's go!

Yikes!

I want to grab
the flowers.

-[glass shatters]
-[laughing]: Oh, fight!

Mah-Jing came up
the side of the corner

and snatches them
out of my hand.

You're not gonna take
all of the flowers,

I want to use some to.

[glass shatters]

My bad!

I'm glad you're laughing!

HEIDI:
My God!

I just go straight towards
the yellow wigs.

And just went crazy with yellow.

Thirty seconds.

Oh, my God!

[Jenni laughs]

Ah! No!

HEIDI:
Five, four,

three,

two,

one, let go.

[whooping]

-You guys rocked it!

I am sending you
to the work room

to get settled in,

and I will join you very soon.

I'll see you on the runway.

-[laughter] -Bye, everybody!
-Head off to the work room!

Oh, man, I probably
didn't grab enough so

hopefully, this will work.

HEIDI: My God,
they really bashed this place.

I think we deserve a drink now.

TIM:
Are there are any glasses?

Mm. There are no glasses,
but there are two bottles.

One for you,

one for me!

[both laugh]

[corks pop]

-[screams]
-Wow!

Cheers, Heidi!

-To season 15!
-15.

Mmm.

That's nice, and it cuts out
the middle man.

-[laughs]
-I like it.

Oh, my gosh!

Okay. [laughs]

-Ooh!
-MAH-JING: Where am I at?

-Okay.
-Right here! [laughs]

Whoa. I'm here.

I'm in the work room.
This is official.

Another surreal moment.

It's something I have seen

on TV for so long, and now,

it's me standing there.
This is awesome.

-It is!
-This is great, yeah! [laughs]

-Hello. -Hi!
-Hi, Tim! -Hello!

TIM: Welcome to
your fabulous work room!

-Do you like it? Good.
-ALL: Yes!

Speaking of fabulous, we have
the JustFab accessories wall,

for your use this entire season.

We have the Brother sewing room,

which is behind this wall.

Work hard, and have fun
with this challenge, okay?

-Okay. -And I will see you
a little later.

♪ ♪

-What is this,
the candy wrappers?
-Yeah!

-Oh, the taffy?
-Yeah.

So there's this theory that

from an evolutionary
standpoint,

that humans are drawn toward

shiny objects, because of their
constant search for water.

So, I think, like anybody,
I'm attracted to glitter.

I'd love to make

bell bottom pants

covered in glitter.

Growing up in Baton Rouge
is not a fashionable place.

All I knew of fashion was my
Mom would take us to Mervyn's.

And now, fashion is my art.

My ultimate way of expressing
who I am as a person.

And as an artist,

expression is the priority.

♪ ♪

Perfect.

-Oh, this is such a cute...
-I know, aren't they cute?

I'm gonna use some of them on
the dress, for sure.

I decided on a shift.

The screens are gonna
be like my basis.

It's gonna be simple.
I mean, it is.

I never finished my degree.

School wasn't for me,
basically.

So, I'm essentially
self-taught.

I don't make wearable art,
I make clothes

that you should
be able to wear.

It's not that I can't make it,

I just don't like to do it.

[laughs]

♪ ♪

I'm going towards
some type of

of low-crotch pants,

probably elongated type of top.

MAH-JING:
So, how y'all feeling so far?

I don't feel good.
[laughs]

-You don't?
-No.

-Pray it off.
-I am.

Pray it off.

Yeah you're trying
to be creative

but at the same time,
you think about,

I don't want to go home
the first challenge.

Thank you, Miss Kimber.

-Hi.
-Hello.

-Hey, Tim! -Hello!
-Hey, Tim!

So, it's our first critique
session-- how exciting!

-Yay.
-Is everyone feeling ready?

-Yeah!
-Great! I can't wait!

I definitely don't want
to let Tim Gunn down.

I'd be ashamed
if I were that person.

-Brik.
-Hello, hi, Tim.

I'm eager to hear
everything about this.

I found these
big bowls of glitter.

And I wanted to make
a fun, fitted,

and with a little flare
at the bottom pant.

How is the glitter adhered?

A various cornucopia of glues.

-[laughs]
-Um...

it just wants to go
to the floor or on me.

So, you are going
to put more on.

Yes, yes.

Good, 'cause quite frankly,

this is a real wow factor.

-Carry on, Brik, okay.
-I will, I will.

Going into Tim's critique,
I'm not nervous at all.

Part of being an artist
is, like, getting crit.

-Ian.
-Hi, Tim.

You don't take it personally.

While I respect your aesthetic,

it seems very basic.

I mean, honestly,

this is, like, a lot of work.

I would just consider

doing something
that makes it look

more fully integrated
into the garment,

as opposed to something
that's-that's Velcroed on,

that we could just take off.

IAN:
Aesthetically,

I do not do avant garde,
like, at all.

So, it would be difficult
for me to be true to myself

as a designer, just like,
putting stuff on there

for the sake
of putting it on there.

I want you to be who you are.
It's just,

if you think about

expanding this
into more volume--

I hate volume.

I respect Tim 100%,

but I don't really think
I'm gonna change much.

Like, at all.

I don't like to do [bleep]
over the top.

Tim says Ian's outfit
is missing flair.

Ding, ding, ding--
change your outfit, Ian.

So, I was thinking
I could create

a skirt out of this,
but I just don't want the judges

to be like,
"Oh, it's the Tin Man's wife."

It's a very over-the-top look.

You made a commitment to this.

Own the bride of Tin Man.

Okay!

This is stunning.

I love how you've
used these plates.

In fact, I wouldn't
even know what they were,

-which is fantastic.
-Awesome!

Alex.

-Hi, Tim.
-So, talk to me.

I'm kind of liking
the angular shapes on them.

It's extremely elegant.

And I like how
you've used the polka dot.

And I like the overall
silhouette.

And I like
the surprise element.

[exhales]
Okay!

-How are you doing?
-What I want to do is kind of

like this off the shoulder...

and it will kind of
look like a fur coat.

So, what's happening
down below?

I've been, like,
cutting the tracks

to be, like, fringe,
and then I use the gumballs,

and I cut them in half, and
then, I was using these beads.

-All right, thank you.
-Thanks.

Talk to me.

I got to work with the lanterns.

Then, I discovered they were

capable of doing
very interesting shapes.

-Yeah. -And starting playing
with the shapes.

Roberi's look

is just insane.

I love it.

I'm eager to see

how this continues
to evolve.

Holy crap, this is who
I'm competing against.

The beads, you're
using them as a necklace.

It's the unconventional
materials challenge, and then,

you've used it
very conventionally.

If I were a judge,
I might put you in the bottom.

I have a very positive response

-to how organic this is.
-Okay, okay.

I just think
this shoulder treatment,

I don't know
that you want to go for

that Madonna, Galliano moment.

-How are you?
-Hey.

I'm getting a little

Andy Warhol,
Jackson Pollock, Banksy.

I'm now a painter;
your average Picasso.

It's now become

a fine arts painting project.
-Right.

Have you just given
lip service

to unconventional materials?

I did manage
to grab some boas.

-Okay.
-And I was gonna create a fur.

But it was too costume,
like a fur shroud...

I mean, at least you're
introducing another material.

Right.

I'll make it work.

-You have to. -I have to.
-Alright, designers.

I'm very excited about
the work that you're doing.

And for most of you,
you have a lot of work to do.

You have two hours remaining.

Your models will be in
in one hour.

♪ ♪

Look at that.
[laughs]

RIK: Erin has nothing
up on the dress form.

She's over in the corner,

just messing around
with trinkets.

Eating Pixy Stix.

If Erin gets the wrong girl,
it could be a problem.

If I got a super pale redhead,

and I had to put yellow on her,
I would die.

♪ ♪

[indistinct chatter]

All right.

Yeah. You got booty, girl.

[laughs]

Sorry.

Here you go.

I grabbed a rug at the party.

And I'm using that
to make my design.

I'm feeling much better,
but not great.

I know that I only have,
like a skirt made,

and there's no top,

but I'm feeling very confident
that I'm going to get

everything that need
to get done.

-Be good.
-Bye.

Okay. In 40 minutes,

I can re-sew this entire thing.

If I can just knock this top
out in one hour,

I will be fine.

If this top
takes me three hours,

I am triple-[bleep].

Erin, I can't wait
to see your look.

ERIN:
I think people are worried about

whether or not I'm gonna
be done on time.

But I think a lot,
and then I act.

DEXTER [mimicking Tim]:
Designers!

You don't have to go home,

but you have to get the hell
out of here.

Time to go.
We're done!

[whooping]

♪ ♪

I'm done.
I'm so happy I'm done.

I have to do some sewing, still.

We are gonna be the four people
that make it to the top, so.

-CORNELIUS: Absolutely.
-Hey.

CORNELIUS:
I already know that.

I really love my look

but you never know--
it's the first time

we're going to be facing
the judges,

so it could be very good,
or very bad.

I'm really, really nervous.
I'm really scared.

I cannot go home
on the first episode.

If they have nothing good,
it'd just tear me to pieces.

That ain't a dream of mine.

♪ ♪

-Whoa!
-Ha!

JENNI:
Time to work, everybody!

I have tunnel vision.
It's like you're drunk

on the way home, and you're
trying to get your key

in the door, and you're just
trying to get there.

That's what it feels like.
All I can see

is that runway at the end.

Good morning, everyone.

ALL: Good morning!

All right,
it's our first runway.

-How exciting is this?
-Yay!

Yes.

You will have two hours

to send your models to the

Mary Kay Color Design Studio,

and to the Sally Beauty Studio,
all right?

Use the JustFab accessories wall
very thoughtfully.

-Okay? Thank you!
-Thank you.

TASHA: Bye, Tim!

Erin, she's still
gluing gumballs on

and we don't have
that much time left.

-IAN: Hi!
-TASHA: Hey, girl.

IAN:
Sorry, I'm like, so short.

I need, like, a step stool.

I don't even know if we even

have to lace it up.

-You're into it?
-Yes.

It looks finished.

I would not change anything.

You know, it's not Tim's dress.

It's mine.

So, you design for a hip girl,
huh?

Mm-hmm.

We have a collection,
Runway Bold.

TASHA:
Yeah. Those colors are nice.

That has all of these
sort of colors.

TASHA:
Oh, that's beautiful.

This looks so amazing on.

It's called a gel semi-matte.

I'll have you put it on.

-But look at that.
-TASHA: Yeah. I like that.

[camera shutter clicks]

I want deep fuchsia, bright lip.

-Uh-huh. Uh-huh.
-And then, I would like

the inside of the eye
to look yellow, if you have it.

And then fade out,

into, like, the same fuchsia.

Okay. We feel you.

[camera shutter clicks]

I would like her to have
cotton candy hair.

Almost cloudlike.

Maybe collapse down
through the center...

-Yes. -...so she gets kind
of an expansion this way?

The outfit's kind of crazy,
so I want to go

very simple with the hair.

-Like, a middle part...
-Okay.

...and then, just like a nice
simple bun in the back.

Cool.
Less is more.

[camera shutter clicks]

So, I was thinking,

some sort of braid.

Maybe along the...

the line right here?

-Okay.
-Like, sort of a crown?

We got it.

[camera shutter clicks]

♪ ♪

Designers, in ten minutes,

you and your models and I

are going down
to the runway,

all right?

[designers groaning]

Ten minutes, everyone.

Brik, he's running around

like a crazy man
without a head on.

And then, turn towards me.

Designers and models,

we are going down to the runway

for our first runway show.

-[whooping]
-TIM: How exciting.

All right, let's go, go, go!

It's the point of no return,
at this point.

All right.

Things are looking good.

IAN:
Oh, I made it.

As long as I made it,
I'm so happy.

-[applause, whooping]
-Hi, guys.

-CORNELIUS: Yeah, girl!
-Wow!

-I like this excitement already.
-[soft laughter]

Welcome to the runway.

As you know, in fashion,
one day you're in,

and the next day, you're out.

There are 16 of you here,
and after tonight,

there will be 15.

Now, for the big prize.

The winner of Project Runway
will receive

$100,000 to launch their line.

A year's supply of Sally Beauty
products, along with

-$25,000 cash.
-[soft laughter]

Travel and hotel accommodations

to inspiring destinations

around the world from
Best Western Hotels and Resorts.

A New Lexus IS.

[laughter]

From Mary Kay, an entire year's
worth of beauty products

for their fashion shows,

and professional makeup artist

services for their debut show.

A complete sewing
and crafting studio

from Brother Sewing
and Embroidery.

And the winning designer
and model will receive

a fashion spread in
Marie Claire magazine.

All right, let's say hello
to our judges.

First, we have creative director

for Brooks Brothers Women
and fashion designer, Zac Posen.

-[applause]
-Hi, designers.

Creative director

for Marie Claire magazine,
Nina Garcia.

-[applause]
-Welcome.

And Today show co-anchor
and Project Runway super fan--

It's true.

...and expectant mother,
Savannah Guthrie.

Welcome.

-[applause]
-Thank you.

Also, we love

having Tim Gunn here,

for the runway show.

And as you know,
he is your mentor,

and will not be judging
your looks.

We also have an anonymous
runway show.

No favorites here.
Okay?

Let's start the show.

♪ ♪

I think my model looks dope,

sexy, confident.

She k*lling it.

I'm like, "Yeah. I'm making
an impression."

I took backpacks and boas

and created
a three-piece garment.

And it's all hand-painted.

That [bleep] looks
like Picasso.

It's cute.

The light hits it.
I think it is beautiful.

I think it communicates
what I wanted to communicate.

And this is what the judges
sort of want to see.

They want to see variety.

They want to see different
points of views.

I'm feeling very good
about my piece in relation

to everybody else's piece.

I created
a textile out of place mats,

and it just
looks amazing.

It has a great

runway effect,
and the judges

seem to enjoy it,

so, I'm happy.

I feel like my garment
definitely represents me

as a designer.

I do take a lot of risks,
and I hope that

they keep me here,
so that I can give them


they've ever seen

in Project Runway history.

I feel extremely excited,
and I love

the way that she walks.

She is definitely
working the runway.

It's beautiful.

It's got just enough sparkle.

I mean, texturally,

it's, like, very strong.

I think the palette is amazing.

Like, I could base

a collection off of that dress.

I'm lovin' the way
she's walking out.

The attitude she's giving.

She's really working
this outfit.

She's working
that little handbag

that I made.

She's really selling
the type of girl

that I design for.

I'm feeling so proud.

Yellow is definitely
one of those colors

that's a hit or a miss color,
and I'm feeling like

I'm sending something bold
down the runway.

Wow, she looks beautiful.

She looks edgy.

She looks innocent.

Just fabulous.

JENNI:
It looks really good.

I'm speechless.

She's gorgeous.

She's k*lling it.

This explains everything
about me

from head to toe.

So, yeah, it's scary.

I didn't use much color,

and the top that I used

is close to muslin.

So, at this point,
I'm just praying

that I make it
through the next round.

I'm happy with my look.

It looks cool.
It looks crazy.

It looks unconventional.

This is either gonna
be on the bottom,

or on the top,
because I went all out for it.

I'm hoping the judges

see that I took

the plates and cut them
at angles,

so that it
kind of reads as petals

towards the flowers that are

incorporated in the top piece.

Because I love it.

I really feel that

my design represents

me as a designer.

It is what I wanted to create.

It's quite
an amazing experience.

The model turns the corner

and I about wet my basement,

because it looks stunning,
and my model

was just shining.

And I am extremely happy
with what I put forward.

I have to say this was a very,
very exciting runway show.

I mean, this was the best
beginning that I've had

in the five years
that I've been on the show.

I love that we chose

this unconventional challenge

to start them off
and really get

their creative juices flowing.

Okay, designers.

We have just learned
which designer

created which look.

If I call your name,
please step forward.

Roberi.

Dexter.

Tasha.

Erin.

Ian.

Brik.

If I have not called your name,
congratulations.

Your scores have qualified you
to move on

to the next round.
You can leave the runway.

JENNI:
Oh, my gosh.

-ALEX: All righty.
-NATHALIA: We did it.

-SARAH: Yeah.
-KIMBER: Oh.

SARAH: Neither the top
nor the bottom.

I have to say,
this is gonna be...

SARAH:
It's gonna be crazy.

...one tough season.

The six of you have the highest

and the lowest scores.

One of you will be named

the winner, and one of you

will be out.

♪ ♪

All right, I would like
to start with you, Tasha.

Tell us how this look

represents you

as a designer and about

the materials that you used.

TASHA: I'm a designer

for sexy and street.

Loud, colorful.

The urban girl.

And, um, for the bag I used

the director's chair.

Uh-huh.

I used Mood's reusable bags.

I used Twizzlers.

Um, a pillow case and backpacks

that we had in the room,
as well.

I have to say, I love this look.

-I see a girl like this
-[softly]: Thank you.

walking down the street
right now,

and I would say,
"Wow, she looks really cool."

She just looks like

an urban girl that you

would see today.

-Great job.
-Thank you.

-The look was very effective.
-Thank you.

NINA: Her clothes say,
"I've got attitude."

The shape of the pants,
the proportion.

This is you.

Thank you so much.

My favorite thing is
that you made a bag

with Tim and Heidi's
names on it.

[laughs]

I think the silhouette
is really cool,

and you pulled it off.

For us regular women,

that's a tough one to wear,

but she looks gorgeous.

Mission accomplished.
You did it.

Blessings.
Thank y'all, so much.

Brik.

Tell us about the materials

that you used.

So, I ended up finding

these big tubs of glitter.

I started off and drafted
a pant, uh, with a flare leg.

And, um, I... luckily,

collected all of these hats.

Ah! That's what that is.

So, I wanted something

that was structured,

and to show what I can do
as a tailor.

I have to tell you,

she looks mismatched to me.

-On top, she looks
very futuristic. -Yeah.

And the bottom
kind of looks retro, disco.

I mean, it's like
Lady Gaga on top,

ABBA on the bottom.

She's got many personalities.

-ZAC: She's got a lot--
and Heidi... -[laughs]

And Rebecca of Sunnybrook

-SAVANNAH: ...at the top...
-ZAC: Totally.

meets Star Wars
meets Studio 54.

Erin. Tell us about your look,

and who you are as a designer.

So, I love fun,

and just, energy, in my work.

-And I... I...
-[sarcastic]: No.

[laughs]

-[laughter]
-Um...

and this is actually,

um, the wig, with, like,
the netting in it.

And these are gumballs.

And then, this is more
of the tracks that I just, like,

trimmed to, like,
look like fringe.

Wow.

This, to me,

is a standout look.

I love the color.

It shows me who you are.

It shows me that
you're about fun, but also,

you have great ideas,

and you make it slick
and perfect looking.

Thank you.

Just a complete expl*si*n

of color walking
down the runway.

I love that halter top.

I think it's so pretty.

It's so universally flattering.

I think it looks beautiful.

Thank you.

Dexter.

-Hi.
-HEIDI: Tell us about

the materials that you used.

I used this, um, rug I found,

um, and then these
are different pillows

that I broke apart
and sewed together

into different patterns.

I kind of wanted to have that

Alaskan mountain tribe,
like, um,

girl's coming-of-age party,

but I wanted to, like,
keep it current

with more of, like,
a-a circle skirt.

And, um, I took
little pieces of it

and put it on the shoes, because
I thought the pop of color

would really, like,
help bring it all together.

I definitely got Alaskan poodle.

You know, it had
that Inuit tribe references,

and I'm happy that you had
a story behind it.

I like how you played
with the pattern.

And it was effective
when it went down the runway.

But I think you can go
even further.

-Good job.
-Thank you.

It was a runway piece.

It had this incredible volume,

which is really happening
in fashion quite a lot.

You used the rug and made it

have volume and movement.

It looks tribal.

-And very chic.
-Thank you.

And then, I love your little
details. I love the fact that

you put those bracelets
on her ankle.

I like this very much.

[sighs]

Ian. Tell us what materials
you used for your look.

I built a shift piece,
basically.

And used, um,

everything that I did to kind of

try to give something
that doesn't move movement.

What I grabbed were, um,

those big screens,
the printed photographs

that were hanging up
on the wall.

I grabbed a couple of pillows

that had, like, tassel detail,
which I really like.

It's a little like
My Little Pony scheme

which is, like,
kind of my thing.

And I grabbed
all of the Polaroids.

I actually, like,
really love it.

I think she looks fantastic.

[sighs]
I did not love this dress.

You just said it yourself.

It's a basic shift dress.

There's no magic for me
in this dress.

You didn't create something
with the Polaroids.

Like, they look like,

boom, boom, there's two
Polaroids glued on.

It's such a great challenge.

The sky's the limit.

You could go nuts with this,

and really show us something
that sings and dances.

And this, to me,

doesn't really have any of that.

I feel like you didn't
use this opportunity.

It was a risk, going minimal.

Just because, I mean, that is
sort of true to who I am.

I do not really work
with a lot of volume

because I don't like it,
not because I can't.

It just really fell short,
for me.

And it also doesn't
look that neat.

You know, on the back, when...
Can she turn, the model?

You know,
everything's symmetrical,

but from her waist down,
they start,

you know, to kind of
shift to the side.

I actually thought the texture
was very interesting.

I thought those icy colors that
you chose were very beautiful.

Unfortunately, it doesn't feel
like you were creative enough.

I feel like you should've
pushed yourself a little more.

Roberi.
Tell us about your look.

I wanted to work
with the lanterns,

because I-I really felt that
the material were very light.

So for me was very interesting

to twist the shapes,
swirl forms, very organic.

And the fantasy of creating
something cloudlike

started taking shapes

inspired by, just, movements
in the clouds and the sky.

I have to say, when this
came around the corner,

I kind of gasped.
But not in a good way.

I don't know. I didn't like
the colors together.

I thought it was too short
when she walked out.

I didn't even really
respond to it as fashion.

I have seen this dress.

And I've seen it
in Project Runway

many times with
many different versions.

There is no balance.

It's all, like, up there.

I know that you two
didn't like it so much,

but I actually
really love this dress.

We have seen pretty much
everything already,

and everything
gets reinvented again

and everyone uses something
from something else.

This, though,
we have not seen before.

And it is the way
you interlocked them

that created this
beautiful sculpture.

I actually love
the colors together.

I love the silver, the white,

the gold and the blue.

I also don't mind
that it is short.

Will you turn around? Can I see
the back one more time?

Let's do a little...

I think it is really pretty.

I mean, it does have
some poetry to it.

The way it just
weaves and curls,

and it leaves me wanting to see
more of what you can do.

I thought it was
incredibly sensitive.

I think it's actually
beautifully done.

Thank you.

Okay. We've heard
what you had to say.

We're gonna have a little chat

and then I'm gonna call you
back. Thank you.

-Hello, judges.
-Hi, Tim! -Hi, Tim!

What a wonderful
kickoff challenge.

-I know.
-HEIDI: Yes. Hello, ladies.

-We couldn't have a better
beginning. -HEIDI: All righty.

Okay, we have Keke
wearing Tasha.

HEIDI: They look better
on the runway than up close!

-It's... very cool.
-You know, because

they're just really
hard to sew, and...

NINA:
Tim, are these plastic...

-They're Mood bags
that she cut up. -Mood bags.

-ZAC: Wow.

-And these are Twizzlers. Yes.
-TIM: Yes.

The best thing is the vibe

-that it sends off.
-TIM: Yeah. -The attitude.

-Including the girl
with the bag. -How great.

How fun.

-I need that bag. [laughs]
-TIM: Director's chairs.

My Tim and Heidi bag.

[laughs]

-TIM: And we have Sherica
wearing Erin. -ZAC: Yeah. Wow.

Unbelievable.

-Fanned out. -NINA: This is
what I love. -Wow.

-The mesh that she did
right here. -Yeah.

-ZAC: The wig mesh.
-I mean, how do you even cut

those gumballs in half?

-I don't know.
-Without cracking them?

She didn't just use it
as crazy down here, again.

-Yeah. -You know, she made it,
like, so...

It-'s balanced.
-...precise.

It's balanced.

And we have Stacy
wearing Dexter.

HEIDI: This, too, I thought
was very cool.

I think this guy has good taste.

-Yes. -Down to the little
detail of the bracelet,

and he did the shoe...

The whole styling...
He's got taste.

-That's what I'm saying.
-For sure.

-I loved it.
-I loved it, too.

TIM: Coming up,
Paola's wearing Roberi.

[sighs]

NINA: I've seen this dress,
Tim Gunn...

But out of, uh...
paper lanterns?

This back is really,
really good.

HEIDI:
It has poetry. It is beautiful,

-it looks like hair.
-I'm impressed.

And I just want to underscore
how incredibly complex

-this was to engineer correctly.
-You bet.

TIM:
And we have Anna, wearing Brik.

-ZAC: Dancing queen.
-HEIDI: Oy vey.

I mean, really,
the only cool thing

about this whole thing

is really the shoulders.

That was really cool and new.

I mean, you can say the pants
fit nice on the booty.

I mean, I guess he can tailor

a nice pair of pants.
But then, why...

How can he not see
that they're too short?

Well, it could've been
a mistake.

NINA: That's not, that's not
even what worries me.

It's the overall styling.

-It's very disjointed.
-Mix-match.

So is this just muslin, and then
just the confetti on the...?

Yeah, he just glued confetti on.

I mean, it's actually, for me,
and, you know...

I don't know. Maybe the sparkly
person in me, I kind of...

there's something
fun in there.

-I don't mind the sparkles.
-As a textile...

There's a spirit.

TIM: And we have Priscilla
wearing Ian.

-I'm sad about this.
-Oh.

ZAC: So, he went into
a lot about, like,

all the work
that he did in here.

So how did he do this? Was that
the fringe around the...

TIM:
I'm not altogether certain

where they came from.

To me, this looks like
you can buy this

-on a roll at Mood.
-[snoring]

But you have
to respect a designer

that has a minimalist stance.

I think he has good taste.

Thank you very much, judges.

Anna and Keke.

Thank you, all!

Really today,
it's between Dexter and Erin.

Erin was, in a way,
more elegant.

There was such balance
in her work. Beautiful.

Dexter, in a way, has more
of a cooler vibe to it.

-He had a vision.
-It was effective.

Yeah. We have not seen anything
like this.

He's very fashion-forward.

Let's talk about the designers
that we did not like.

-Brik was the worst.
-To me,

Brik's was more creative
than Ian's.

To me, Ian's was more
sophisticated than Brik's.

Creative versus sophistication.

That's where
we are coming to here.

Okay.
So, we've made our decision.

♪ ♪

Designers, one of you
will be named the winner,

and one of you will be out.

Erin.

Congratulations, you are the
winner of the first challenge.

Thank you.
Thanks, guys. [chuckling]

Are you excited?

It's a really good feeling.
Yeah.

HEIDI:
And we all can't wait

to see
what you're gonna do next.

Congratulations.
You can leave the runway.

Thank you.

It's so wild
being the first winner.

There's no better way
to start the season.

-She did it really fast. [gasps]
-And then she just made it.

-What happened?
-Are you the winner?

Like, I was just like...

"Cool." [chuckles]

-Yes!
-[cheering and applause]

Dexter, you're in.

You can leave the runway.

Thank you guys so much.

Tasha, you did a great job.

You're in.
You can leave the runway.

Thank y'all so much. Thank you.

[quietly]:
Good luck.

Roberi, you're in.

You can leave the runway.

Thank you.

Ian,

your dress was not our favorite.

The final look was uninspiring

and underwhelming.

Brik.

There was
a really big disconnect

to your look.

It just did not come together.

Brik...

...you're in.

You can leave the runway.

Thank y'all.

I'm sorry, buddy.

[Heidi sighs heavily]

Ian, I'm sorry.
That means you're out.

It must be so hard
being the first one.

It's all right.
I like the dress, so...

We wish you the best of luck.

Auf Wiedersehen.

IAN:
I love the dress.

I, like, can't say it enough.
The people

that I met are, like, a nice
concession prize, I guess.

-We're here.
-Yeah. -Yeah.

-Hey...
-No...

It's all good.

I loved it. So...

If you're proud of it,
then that's all that matters.

-That's all that matters.
-Yeah. Yeah.

-Yeah!
-Okay, group hug!

-Aw! I know you don't like hugs!
-Group hug!

I'm really proud that I stood up
for myself in front of them.

I mean, it's intimidating.
It really is. But...

I would be embarrassed
of myself

if I didn't stand up for myself
and my work.

[indistinct chatter]

-No...
-Hi. -Hello.

Ian, we're gonna miss
your spunk.

-[chuckles]
-Tremendously.

I have to send you to the work
room to clean out your space.

-Sure. Yeah.
-Okay?

-It's been good, guys! k*ll it!
-ALL: Bye.

It was an experience,
that's for sure.

I don't regret it for a second.

My work was beautiful.

And I'll swear by that
till the day I die.

HEIDI:
Next time on...

Oh, snap.

TASHA:
Here comes this army of women.

There's women coming from
the left, from the right, from

-the north side, south side.
-Oh, wow.

Whatever drama you guys
have going on, just, like,

I don't even want to be,
like, a part of it.

DEXTER:
I'm trying to ignore Cornelius

because he's always
talking [bleep] about someone.

-My skirt has a hole in it and I
can't even repair it. -[yelping]

This is not the time
for this kind of bull[bleep].

-She looks great.
-That is my kind of girl.

It looks shabby.

It's like weird officewear.

It's kind of sad.